
------------------------------------------------
-- DDL Statements for table USAGERECORDS
------------------------------------------------

DROP TABLE USAGEPROPERTIES;
DROP TABLE USAGERECORDS;
 
CREATE TABLE USAGERECORDS
  (RECORDID VARCHAR(127) NOT NULL, 
   GLOBALID VARCHAR(127), 
   SERVICEIMPLNAME VARCHAR(127), 
   EVENTTYPE VARCHAR(127), 
   EVENTSEQ INTEGER, 
   RECORDTIME TIMESTAMP, 
   STATUSCODE INTEGER );

-- DDL Statements for primary key on Table "USAGERECORDS"

ALTER TABLE USAGERECORDS 
  ADD CONSTRAINT "CC1138311823119" PRIMARY KEY (RECORDID);

-- Comments for the Table

COMMENT ON TABLE USAGERECORDS IS 'Usage record entry.';

COMMENT ON COLUMN USAGERECORDS.RECORDID IS 'Unique record identifier.';
COMMENT ON COLUMN USAGERECORDS.GLOBALID IS 'Global transaction identifier that created this usage record.';
COMMENT ON COLUMN USAGERECORDS.SERVICEIMPLNAME IS 'Service identifier that created this usage record.';
COMMENT ON COLUMN USAGERECORDS.EVENTTYPE IS 'Type of event for this usage record.';
COMMENT ON COLUMN USAGERECORDS.EVENTSEQ IS 'Event sequence number for the event type.';
COMMENT ON COLUMN USAGERECORDS.RECORDTIME IS 'Timestamp when this event occurred.';
COMMENT ON COLUMN USAGERECORDS.STATUSCODE IS 'Status of the usage record.';

------------------------------------------------
-- DDL Statements for table "USAGEPROPERTIES"
------------------------------------------------

 
CREATE TABLE USAGEPROPERTIES  
  (PROPERTYID VARCHAR(127) NOT NULL, 
   RECORDID VARCHAR(127) NOT NULL, 
   ATTRIBUTE VARCHAR(400), 
   VALUE VARCHAR(2800) ); 

-- DDL Statements for primary key on Table "USAGEPROPERTIES"

ALTER TABLE USAGEPROPERTIES
  ADD CONSTRAINT "CC1138310365312" PRIMARY KEY (PROPERTYID, RECORDID);

-- DDL Statements for foreign keys on Table "USAGEPROPERTIES"

ALTER TABLE USAGEPROPERTIES
  ADD CONSTRAINT "CC1138829353206" FOREIGN KEY (RECORDID)
	REFERENCES USAGERECORDS (RECORDID)
	ON DELETE CASCADE;
        
-- Comments for the Table

COMMENT ON TABLE USAGEPROPERTIES IS 'Usage record properties.';

COMMENT ON COLUMN USAGEPROPERTIES.PROPERTYID IS 'Unique identifier for the property of a given record ID.';
COMMENT ON COLUMN USAGEPROPERTIES.RECORDID IS 'Unique record identifier from the UsageRecords table.';
COMMENT ON COLUMN USAGEPROPERTIES.ATTRIBUTE IS 'Name of the property.';
COMMENT ON COLUMN USAGEPROPERTIES.VALUE IS 'Value of the property.';

QUIT;
